@@ -5,6 +5,7 @@
 
 #include <dirent.h>
 #include <fcntl.h>
+#include <set>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -29,6 +30,9 @@ private:
 
     DIR *m_dir = nullptr;
     int m_dirfd = -1;
+    // Hard link files we have already counted, so we will ignore them
+    std::set<ino_t> m_countedHardlinks;
+
     struct stat statbuf {
     };
     Q_DISABLE_COPY_MOVE(POSIXWalker) // we hold a pointer, disable sharing
